#
# spec file for package help2man
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           help2man
Version:        1.49.3
Release:        1.10
Summary:        Script for generating man pages from --help output
License:        GPL-3.0-or-later
Group:          Development/Tools/Doc Generators
URL:            https://www.gnu.org/software/help2man/
Source0:        https://ftp.gnu.org/gnu/help2man/%{name}-%{version}.tar.xz
Source1:        https://ftp.gnu.org/gnu/help2man/%{name}-%{version}.tar.xz.sig
Source2:        %{name}.keyring
BuildRequires:  perl-gettext
Requires:       perl-gettext
Recommends:     %{name}-lang

%description
help2man is a script to create simple man pages from the --help and
--version output of programs.

Since most GNU documentation is now in info format, this provides a way
to generate a placeholder man page pointing to that resource while
still providing some useful information.

%lang_package

%prep
%setup -q

%build
%configure \
	--enable-nls
%make_build

%install
%make_install

%find_lang %{name} --with-man

%files
%license COPYING
%doc NEWS README THANKS debian/changelog
%{_bindir}/help2man
%{_libdir}/help2man/
%{_infodir}/help2man.info%{?ext_info}
%{_mandir}/man1/help2man.1%{?ext_man}

%files lang -f %{name}.lang
%license COPYING
%{_infodir}/help2man-*.info%{?ext_info}
%dir %{_mandir}/??
%dir %{_mandir}/??/man1

%changelog
* Sat Dec 17 2022 Dirk Müller <dmueller@suse.com>
- update to 1.49.3:
  * Cleanup whitespace in po-texi/help2man-texi.pot.
  * Add Korean translation (thanks to Seong-ho Cho).
* Fri Apr 15 2022 Dirk Müller <dmueller@suse.com>
- update to 1.49.2:
  * Add configure~ to mostlyclean target.
  * Add Romanian translations (thanks to Remus-Gabriel Chelu).
* Thu Feb 17 2022 Andreas Stieger <andreas.stieger@gmx.de>
- help2man 1.49.1:
  * Use @samp{} around the option in the menu description for
    "--help recommendations" to avoid rendering the -- as endash
  * Don't translate @documentencoding
  * Fall back to forking iconv for encodings which are not
    supported by Perl's Encode module
* Fri Sep 17 2021 Bernhard Voelker <mail@bernhard-voelker.de>
- help2man 1.48.5:
  * Update French translations
* Sun Aug  8 2021 Andreas Stieger <andreas.stieger@gmx.de>
- help2man 1.48.4:
  * Update Swedish translations
* Fri Apr  2 2021 Andreas Stieger <andreas.stieger@gmx.de>
- help2man 1.48.3:
  * Don't translate @documentencoding
  * Update Serbian translations
  * Update Esperanto translation
* Wed Mar  3 2021 Andreas Stieger <andreas.stieger@gmx.de>
- help2man 1.48.2:
  * Update Chinese (simplified) translation
* Sat Feb  6 2021 Andreas Stieger <andreas.stieger@gmx.de>
- help2man 1.48.1:
  * Add Serbian, Swedish, Brazilian Portuguese and Chinese
    (simplified) translations of info documentation
  * Add Tamil and Chinese (simplified) translations
  * Move table of contents to the top of the texi file so that it
    appears in the correct location in the html page
  * Use the package name and version as the default for --source
    (was program)
  * Support packages in version strings without the GNU or Free
    prefix
  * Allow an optional second dash to separate the package name from
    the version for multi-word packages: "program - package name -
    version"
  * Suppress creation of an empty pkglibdir when nls is disabled
  * Fix ordering of "other" sections in manual page
  * Use POSIX compliant TZ when setting UTC
* Thu Jan 21 2021 Andreas Stieger <andreas.stieger@gmx.de>
- help2man 1.47.17:
  * Add Serbian translation of info page
  * Update Swedish translation
- remove obsolete texinfo packaging macros
* Fri Jul  3 2020 Andreas Stieger <andreas.stieger@gmx.de>
- help2man 1.47.16:
  * Move table of contents to the top of the texi file so that it
    appears in the correct location in the html page
* Tue Apr 28 2020 Andreas Stieger <andreas.stieger@gmx.de>
- help2man 1.47.15:
  * Use the package name and version as the default for --source
    (was program)
  * Support packages in version strings without the GNU or Free
    prefix
  * Allow an optional second dash to separate the package name from
    the version for multi-word packages:
    "program - package name - version"
* Sat Apr 25 2020 Andreas Stieger <andreas.stieger@gmx.de>
- help2man 1.47.14:
  * Revert --version parsing change from 1.47.13.
    Multi-word package names are supported only in form
    "program (GNU package) version"
* Sat Mar 28 2020 Andreas Stieger <andreas.stieger@gmx.de>
- help2man 1.47.13:
  * build system fixes
  * Update parsing of --version to allow multi-word programs when
    constructing the placeholder NAME paragraph
* Sun Jan  5 2020 Andreas Stieger <andreas.stieger@gmx.de>
- help2man 1.47.12:
  * Fix minor error in Spanish translations
  * Fix ordering of "other" sections in manual page
* Tue Aug 27 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Tue Aug 13 2019 Andreas Stieger <andreas.stieger@gmx.de>
- help2man 1.47.11:
  * Set document language for localised info pages
  * Add French and Spanish translation of info documentation
  * Add Spanish and Danish translations
  * Add support for reproducible builds by using $SOURCE_DATE_EPOCH
    as the date for the generated pages
* Tue Jul  9 2019 Martin Pluskal <mpluskal@suse.com>
- Add correct gpg keyring
* Wed Jun 26 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.47.10:
  * Change maintainer sanity check in debian/rules to use the
    contents of README rather than the mtime, which may be have
    been modified by dpkg-source (closes: #925136).
- Changes for version 1.47.9:
  * Add Tamil translation (thanks to Arun Isaac).
- Changes for version help2man 1.47.8:
  * Use $(DEB_VERSION) from pkg-info.mk [lintian].
  * Fix git repository link in generated README.
  * Update debian/copyright to machine readable format [lintian].
  * Update standards version to 4.2.1 (no changes).
- Split lang subpackage
- Use signature to verify sources
* Sat Sep 29 2018 astieger@suse.com
- update to 1.47.7:
  * Add Swedish translation of info page
- includes changes from 1.47.6:
  * Add Brazilian Portuguese translation of info page
  * Update Hungarian translation
  * Update Brazilian Portuguese translation
* Thu Oct  5 2017 riafarov@suse.com
- Update to 1.47.5
  * Refresh Brazilian Portuguese translation from translation project
    copy (trivial date change).
  * Update Swedish translation (thanks to Sebastian Rasmussen).
  * Use POSIX compliant TZ when setting UTC (thanks to Paul Eggert).
  * Update copyright years.
* Tue May 10 2016 mpluskal@suse.com
- Update to 1.47.4
  * Update Serbian translation (thanks to Мирослав Николић).
  * Add Chinese (simplified) translation of info page (thanks to
    Mingye Wang).
  * Update Brazilian Portuguese translation (thanks to Rafael
    Fontenelle).
  * Reduce the minimum translation to 60%% for info files.
  * Extract version from dpkg-parsechangelog using the new flag,
    rather than sed.
  * Add hardening flags via DEB_BUILD_MAINT_OPTIONS.
  * Use secure VCS URIs.
  * Update standards version to 3.9.8.
* Thu Nov 19 2015 astieger@suse.com
- update to 1.47.3:
  * Filter more untranslatable strings from help2man-texi.pot
  * Add note to translators about translation of cross-references.
* Fri Sep 11 2015 mpluskal@suse.com
- Update to 1.47.2
  * Update Esperanto translation (thanks to Felipe Castro).
  * Add Chinese (simplified) translation (thanks to Mingye Wang).
* Mon Jun 15 2015 astieger@suse.com
- update to 1.47.1:
  * Set document language for localised info pages.
  * Add French and Spanish translation of info documentation.
  * Add Spanish and Danish translations.
  * Add support for reproducible builds by using
    $SOURCE_DATE_EPOCH as the date for the generated pages.
* Mon May 11 2015 mpluskal@suse.com
- Update to 1.46.6
  * Add German, Ukranian and Polish translations of info
    documentation.
  * Add Hungarian and Norwegian Bokmaal translations.
* Sat Jan 31 2015 andreas.stieger@gmx.de
- help2man 1.46.5:
  * Fix a problem with LC_ALL being imported twice with different
    prototypes from POSIX and Locale::gettext
  * Update copyright years.
* Mon Oct 13 2014 andreas.stieger@gmx.de
- help2man 1.46.4:
  * Include architecture.mk and buildflags.mk into rules to replace
    the multiple calls to dpkg-architecture and to pick up the
    correct hardening flags.
  * Add $(LDFLAGS) when building preload to pick up -z relro (see
    https://wiki.debian.org/Hardening).
  * Minor correction to Norwegian Bokmaal translation.
  * Minor correction to Brazilian Portuguese translation.
  * Escape dashes in --name flag for groff (see lintian tag:
    hyphen-used-as-minus-sign).
  * Fix example using AM_MISSING_PROG in documentation: this macro no
    longer requires the third argument.
* Sun Oct  5 2014 andreas.stieger@gmx.de
- help2man 1.46.3:
  * Update Serbian translation
  * Add Spanish translation
- includes changes from 1.46.2:
  * Update French translation, and add translation of info page
- verify source signature
* Sat Aug 16 2014 mardnh@gmx.de
- Update to version 1.46.1:
  * Update translations.
  * Apply texinfo patch from Mario Blätterman.
  * Rename aclocal macros with LOCAL_ prefix.
  * Include "missing" program from automake in distribution.
  * Add LOCAL_PROG_OR_MISSING macro.
  * Change reference to standards to avoid spurious comma.
    to Yuri Chornoivan).
    Jakub Bogusz).
  * Move automake helper scripts into a build-aux sub-directory.
  * Add a helper script to locate files in $VPATH.
    + fixup-tex-pot: remove entries from template which should not be
    translated.
    + fixup-texi-trans: add the correct path for install-info and correct the
    alignment of the main menu.
  From 1.45.1:
  * Skip additional blank lines following sections, and provide an
    explicit method of adding sections (thanks to Mischa Williamson).
  * Improve handling of tagged paragraphs when the body is on a following
    line (thanks to Brian Campbell).
  * Add escapes to adjust spacing of italic text at roman/italic
    boundaries (thanks to Bjarni Ingi Gislason, closes: #742289)
  From: 1.44.1:
  * Perform shell word splitting on option lines in include files.
  * Update translations.
  * Update copyright years.
  * Change distribution filename in README to help2man-VERSION.tar.xz
  * Fix gitweb URL in README.
* Tue Jul  9 2013 asterios.dramis@gmail.com
- Update to version 1.43.3:
  * Update translations.
  From 1.43.2:
  * Use the generic term "section" in the documentation rather than "name",
    which could be confused to mean only the literal "NAME" section.
  From 1.43.1:
  * Add explicit include syntax for prepending, replacing or appending to
    generated output for a section (thanks to Daniil Baturin for the idea).
  * Update translations.
  From 1.42.1:
  * Update translations.
  * Consistently strip path and/or libtool "lt-" prefix from any instance
    of $program derived from --help or --version (thanks to Eric Shattow
    for identifying the issue).
  From 1.41.2:
  * Update translations.
* Tue Mar 26 2013 asterios.dramis@gmail.com
- Update to version 1.41.1:
  * Rename configure.in to .ac, and revise use of AC_INIT/AC_OUTPUT macros
    to meet current autoconf guidelines.
  * Add copyright headers to supporting files (GNU All-Permissive License).
  * Fix section name comparisons ($sect is localised).
  * Set filenames in italics.
  * Suppress option/filename handling in EXAMPLES section.
  From 1.40.13:
  * Debian build fixes.
* Sat Oct  6 2012 asterios.dramis@gmail.com
- Update to version 1.40.12:
  * Update Croatian translation.
  * Fix updating of help2man.pot to occur only when help2man.PL is changed, not
    help2man generated.
  From 1.40.11:
  * Add Croatian translation.
* Wed Jun  6 2012 asterios.dramis@gmail.com
- Update to version 1.40.10:
  * Update Greek translation.
  * Update Serbian translation.
  * Update German translation.
- Enabled support for generating localised pages.
* Wed May 23 2012 asterios.dramis@gmail.com
- Update to version 1.40.9:
  * Update Japanese translation.
  * Update Esperanto translation.
  * Update Vietnamese translation.
  * Update German translation.
  From 1.40.8:
  * Update French translation.
  * Update Italian translation.
  * Update Polish translation.
  * Update Russian translation.
  * Update Ukranian translation.
  * Modify self-extracting scripts to output to a temporary file.
  * Ensure that help2man exists before building manual pages.
- Removed "-ggdb" from CFLAGS and CXXFLAGS (no reference was found why this is
  needed).
* Sun Mar 25 2012 asterios.dramis@gmail.com
- Update to version 1.40.7:
  * Update Greek translation.
  From 1.40.6:
  * Fix FSF address in comments.
* Sun Jan  8 2012 asterios.dramis@gmail.com
- Update to version 1.40.5:
  * Clean up some lintian warnings: build-targets, source format and standards
    version.
  * Add Serbian translation.
  * Fix trivial translation changes due to additional copyright year.
  * Minor fix to Italian translation.
* Wed Aug  3 2011 asterios.dramis@gmail.com
- Update to version 1.40.4:
  * Update Brazilian Portuguese translation.
  From 1.40.3:
  * Update Esperanto translation.
  * Update links to git repository.
  From 1.40.2:
  * Remove a superfluous period from texinfo doc.
  * Change footnote about supported languages to a simple paragraph.
  * Update Italian translation.
  * Update Ukrainian translation.
  * Update French translation.
  * Update Japanese translation.
  * Update Russian translation.
  * Update Polish translation.
- Minor spec file updates.
* Sat Jun  4 2011 asterios.dramis@gmail.com
- Update to version 1.40.1:
  * Update texinfo docs.
  * Document --libtool option.
  * Allow date format to be localised.
  * Add Japanese translation.
  * Update Italian translation.
* Tue May  3 2011 asterios.dramis@gmail.com
- Update to version 1.39.3:
  * Add --libtool option to remove `lt-' prefix for libtool programs.
  * Add Italian, Greek, Ukranian, Esperanto translations.
  * Update French, German, Russian, Polish, Finnish translations.
  * Fix Brazilian, Russian and Italian translations.
- Spec file updates:
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Changed License: to GPLv3+.
  * bindtextdomain.so is now installed correctly.
  * Minor other updates.
* Mon Nov  8 2010 davejplater@gmail.com
- Added "Requires: perl-gettext" after using help2man in build
  service blender build to generate a man page for blenderplayer.
* Sat Nov  6 2010 davejplater@gmail.com
- Update to version 1.38.2
- Upstream changes :
  * Support ENVIRONMENT and FILES sections.
  * Move all translated text into .po files (previously .h2m include
  files were handled seperately).
  * Submit package to the Translation Project (translationproject.org).
  * Add Vietnamese translation.
  * Add some comments for translators.
  * Update GPL to v3.
  * Add --version-string option.
  * Add --no-discard-stderr option.
  * Add line breaks into bug reporting section.
  * Add Brazilian Portuguese and German translations.
  * Select a reasonable configure default for --enable-nls.
  * Revise preload mechanism to not require preloadable libintl.
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Mon Sep 21 2009 crrodriguez@suse.de
- tag localized man pages correctly
* Mon May 15 2006 schwab@suse.de
- Update to help2man 1.36.4.
  * Add sv translation from Daniel Nylander (closes: #349568).
  * Updated fr translation from Denis Barbier (closes: #338995).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Nov  2 2005 schwab@suse.de
- Update to help2man 1.36.2.
* Mon Oct 17 2005 schwab@suse.de
- Update to help2man 1.36.1.
* Wed Oct  5 2005 schwab@suse.de
- Update to help2man 1.35.2.
* Thu Sep 29 2005 dmueller@suse.de
- add norootforbuild
* Thu Nov 25 2004 schwab@suse.de
- Update to help2man 1.35.1.
* Wed Nov 24 2004 schwab@suse.de
- Update to help2man 1.34.2.
* Mon Jul 21 2003 schwab@suse.de
- Update to help2man 1.33.1.
* Thu Jul 10 2003 schwab@suse.de
- Compile shared library with -fPIC.
* Thu Jul 10 2003 schwab@suse.de
- Update to help2man 1.31.1.
- Not noarch any more.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Apr  7 2003 schwab@suse.de
- Only delete info entries when removing last version.
* Thu Feb  6 2003 schwab@suse.de
- Use %%install_info.
* Tue Sep 17 2002 schwab@suse.de
- Update to help2man 1.29.
* Tue Jun  4 2002 schwab@suse.de
- Update to version 1.28.
  * New option --info-page.
* Sun Mar 10 2002 schwab@suse.de
- Initial version 1.27.
